;*******************(ASM) COPYRIGHT 2023 Masses-Chip ****************************
;* Project Name		  : M8P6271_USART.Prj
;* File Name		  : M8P6271_USART.ASM
;* Author			  : MASSES CHIP
;* Version			  : V1.06
;* Date				  : 2024/11/18
;* Web				  : www.masses-chip.com
;* FAE				  : Luo
;					  : QQ：411680975
;//******************************************************************************
;
;Option:16M/16T,WDT-Enable-288ms,RST-IO,BOR 2.8V 
;说明：本范例以异步串口通讯，数据长度为8位，串口波特率为38400
;TX端口为IOA3，RX端口为IOA４
;每隔100ms串口发送一字节数据，串口接收数据放在寄存器R_Receive_Data中
;接收到有错误的数据放在寄存器R_Receive_Data_Err中
;//******************************************************************************
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
#INCLUDE zc.INC

;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata	udata       H'00'		
R_Receive_Data		res		1
R_Receive_Data_Err	res		1
R_Delay_Count		res		1
R_Delay_Count_1		res		1

;//===============================================================================
;//******************************** C O D E **************************************
;//===============================================================================
		ORG			0000H
		GOTO		Main_Program
		ORG			0008H
		GOTO		Interrupt

;//===============================================================================
;//*********************************主程序****************************************
;//===============================================================================		
;//-------------------------------程序初始化--------------------------------------	
Main_Program:		
	    CALL		system_Init				;//系统初始化
		CALL		Clr_RAM_00H_7FH		    ;//RAM清零
		CALL		USART_Init				;//USART初始化
;//-------------------------------主函数循环--------------------------------------
Main_Loop:
		CLRWDT								;//清除看门狗
		CALL		Delay_100ms
		CALL		Usaart_Send_Byte
	    GOTO		Main_Loop

;//===============================================================================
;//******************************中断处理程序*************************************
;//注：没有使能的中断不要判断中断标志位
;//===============================================================================
;//中断进来
Interrupt:									;//中断处理程序
        PUSH        						;//进栈、保存A、STATUS
		JBTS1  		INTF0,RXIF      		;//判断中断标志RXIF
		GOTO        Interrupt_End
		JBTS0		RX0CR,1
		GOTO		Receive_Err
		MOVR		RX0REG,A
		MOVAR		R_Receive_Data
		GOTO		Interrupt_End
Receive_Err:
		MOVR		RX0REG,A
		MOVAR		R_Receive_Data_Err

Interrupt_End:								;//中断结束
		POP         						;//出栈、恢复A、STATUS
		RETIE	 

;//===============================================================================
;//******************************延时处理程序*************************************
;//===============================================================================
Delay_100ms:
		MOVIA		250
		MOVAR		R_Delay_Count
		MOVIA		130
		MOVAR		R_Delay_Count_1
Delay_100ms_1:		
		DJZR		R_Delay_Count_1,1
		GOTO		Delay_100ms_2
		RETURN
Delay_100ms_2:
		DJZR		R_Delay_Count,1
		GOTO		$-1
		GOTO		Delay_100ms_1

;//===============================================================================
;//******************************Usart发送子程序**********************************
;//Usart发送数据
;//发送一个字节数据
;//===============================================================================
Usaart_Send_Byte:
		MOVIA		0x12
		MOVAR		TX0REG
		JBTS1		TX0CR,6
		GOTO		$-1
		RETURN

;//===============================================================================
;//*********************************Usart初始化***********************************
;//Usart设置:异步模式，数据长度为8，串口波特率为38400
;//RX口设置为输入，开启串口接收中断
;//===============================================================================	
Usart_Init:
;//1.端口设置
;//   IOA3   TX
;//   IOA4   RX
		BSET		OEA,3	
		BCLR		OEA,4
		MOVIA		0X43
		MOVAR		MPUART
;//2.TXCR 设置	
		MOVIA		0x80	
		MOVAR		TX0CR
;//3.RXCR 设置	
		MOVIA		0x80		
		MOVAR		RX0CR
;//4.波特率设置
		MOVIA		0x00
	    MOVAR		BRGD0H
	    MOVIA		0x67		
	    MOVAR		BRGD0L		 
; ;//串口中断 
        BCLR		INTF0,RXIF   
		BCLR		INTF0,TXIF   
		BSET		INTCR0,RXIE   
        BCLR		INTCR0,TXIE	 
		BSET		OPTION,GIE    
		RETURN

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置IO为数字IO口输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================
SYSTEM_INIT:
;//-----------------------------------------------------------------------
;//SystemInit Clock
		MOVIA      	0x00
        MOVAR      	OSCM
;//----------------------------------------------------------------------
;//Init IO 
		;//IOA
		MOVIA      	0x00    	;//0:上拉关闭 1:上拉使能
        MOVAR      	PUA
        MOVIA      	0xFF    	;//0:输入 1:输出
        MOVAR      	OEA
        MOVIA      	0x00    	;//IO口数据
        MOVAR      	IOA
;//----------------------------------------------------
;//端口模式设置	
		MOVIA		0x00		;//Bit0~6: 0:作为数字IO口 1:作为模拟端口
		MOVAR		ANSA		;//Bit7: 0:IOA3下拉关闭 1:IOA3下拉使能
;//----------------------------------------------------------------------      
;//中断设置  				
		BCLR     	OPTION,GIE  ;//1:总中断使能,0:屏蔽所有中断	
		RETURN

;//===============================================================================
;//*************************** RAM清零(00H~7FH) **********************************
;//RAM清零：RAM区0000H~007FH全部清零
;//===============================================================================        	
Clr_RAM_00H_7FH:
		CLRR		FSR0   		;//从00地址开始写入
Clr_RAM_00H_7FH_LOOP:	
		MOVIA       0x00
		MOVAR		INDF0
		INCR		FSR0,1
		JBTS1		FSR0,7
		GOTO		Clr_RAM_00H_7FH_LOOP
		RETURN
		END

;//*********************************END OF FILE**********************************